/* This file is part of the Nepomuk Project
   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "annotation.h"

#include <QtGui/QIcon>
#include <QtCore/QUrl>


class Nepomuk::Annotation::Private
{
public:
    Resource resource;
    QString label;
    QString comment;
    QIcon icon;
    qreal relevance;
};


Nepomuk::Annotation::Annotation( const Resource& resource, QObject* parent )
    : QObject( parent ),
      d( new Private() )
{
    d->resource = resource;
    d->relevance = 1.0;
}


Nepomuk::Annotation::~Annotation()
{
    delete d;
}


Nepomuk::Resource Nepomuk::Annotation::resource() const
{
    return d->resource;
}


QString Nepomuk::Annotation::label() const
{
    return d->label;
}


QString Nepomuk::Annotation::comment() const
{
    return d->comment;
}


QIcon Nepomuk::Annotation::icon() const
{
    return d->icon;
}


qreal Nepomuk::Annotation::relevance() const
{
    return d->relevance;
}


void Nepomuk::Annotation::create()
{
    // call a protected method to be open for future extensions at
    // this place.
    doCreate();
}

void Nepomuk::Annotation::setLabel( const QString& label )
{
    d->label = label;
}


void Nepomuk::Annotation::setComment( const QString& comment )
{
    d->comment = comment;
}


void Nepomuk::Annotation::setIcon( const QIcon& icon )
{
    d->icon = icon;
}


void Nepomuk::Annotation::setRelevance( qreal r )
{
    d->relevance = qMax( qMin( r, 1.0 ), 0.0 );
}


void Nepomuk::Annotation::emitFinished()
{
    emit finished( this );
    deleteLater();
}


int Nepomuk::Annotation::occurenceCount( const QDateTime&, const QDateTime& ) const
{
    return -1;
}


QDateTime Nepomuk::Annotation::lastUsed() const
{
    return QDateTime();
}


QDateTime Nepomuk::Annotation::firstUsed() const
{
    return QDateTime();
}

#include "annotation.moc"
