/*
   Copyright (c) 2008-2009 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "annotationmodel.h"
#include "annotation.h"
#include "annotationpluginwrapper.h"
#include "annotationplugin.h"
#include "annotationpluginfactory.h"

#include <KIcon>
#include <KDebug>

#include <Nepomuk/Resource>


class Nepomuk::AnnotationModel::Private
{
public:
    Private( AnnotationModel* parent )
        : q( parent ) {
    }

    AnnotationPluginWrapper* wrapper;
    AnnotationPluginFactory* pluginFactory;

    QString filter;

private:
    AnnotationModel* q;
};


Nepomuk::AnnotationModel::AnnotationModel( QObject* parent )
    : AbstractAnnotationModel( parent ),
      d( new Private(this) )
{
    d->pluginFactory = new AnnotationPluginFactory( this );
    d->wrapper = new AnnotationPluginWrapper( this );
    connect( d->wrapper, SIGNAL( newAnnotation( Nepomuk::Annotation* ) ),
             this, SLOT( addNewAnnotation( Nepomuk::Annotation* ) ) );
}


Nepomuk::AnnotationModel::~AnnotationModel()
{
    delete d;
}


void Nepomuk::AnnotationModel::setFilter( const QString& filter )
{
    d->filter = filter;
    updateAnnotations();
}


void Nepomuk::AnnotationModel::doUpdateAnnotations()
{
    d->wrapper->setPlugins( AnnotationPluginFactory::instance()->getPluginsSupportingAnnotationForResource( resource().resourceUri() ) );
    d->wrapper->getPossibleAnnotations( resource(), d->filter );
}

#include "annotationmodel.moc"
