/*
   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef _NEPOMUK_GEONAMES_COUNTRY_FETCH_JOB_H_
#define _NEPOMUK_GEONAMES_COUNTRY_FETCH_JOB_H_

#include <KJob>

#include <QtCore/QUrl>

namespace Soprano {
    namespace Util {
        class AsyncModel;
        class AsyncResult;
    }
}

namespace Nepomuk {
    /**
     * Fetches all countries from geonames and stores them in the local Nepomuk
     * repository in a nrl:InstanceBase graph with label "geonames/countries".
     *
     * This data is used by the GeoNamesAnnotationPlugin to disambiguate the 
     * possible city annotations.
     *
     * \author Sebastian Trueg <trueg@kde.org>
     */
    class GeoNamesCountryFetchJob : public KJob
    {
        Q_OBJECT

    public:
        GeoNamesCountryFetchJob( QObject* parent = 0 );
        ~GeoNamesCountryFetchJob();

        /**
         * Checks the local Nepomuk repository for the geonames countries
         * graph.
         *
         * \return \p true if the graph could be found.
         */
        static bool countriesAlreadyFetched();

        void start();

    private Q_SLOTS:
        void slotCountriesBatchResult( KJob* );
        void fetchNextBatch();

    private:
        void removeOldData();

        int m_fetchedCountriesCount;
        int m_fetchedCountryStatementsCount;
        int m_retryCount;

        QUrl m_countriesGraph;

        Soprano::Util::AsyncModel* m_asyncModel;
    };
}

#endif
