/*
   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "mainwindow.h"
#include "annotationwidget.h"
#include "annotationdisplay.h"

#include <QtGui/QVBoxLayout>

#include <Nepomuk/Thing>

#include <KLocale>
#include <KDebug>


MainWindow::MainWindow( const KUrl& res )
    : QMainWindow()
{
    setWindowTitle( i18n( "Nepomuk - Annotate Resource" ) );
    QWidget* w = new QWidget( this );
    QVBoxLayout* lay = new QVBoxLayout( w );
    m_annotationWidget = new Nepomuk::AnnotationWidget( w );
    m_annotationDisplay = new Nepomuk::AnnotationDisplay( w );
    m_annotationDisplay->setNavigationEnabled( true );
    lay->addWidget( m_annotationWidget );
    lay->addWidget( m_annotationDisplay );
    setCentralWidget( w );
    Nepomuk::Resource resource( res );
    Nepomuk::Thing thing = resource.pimoThing();
    kDebug() << resource.resourceUri() << thing.resourceUri();
    m_annotationWidget->setResource( thing );
    m_annotationDisplay->setResource( thing );
    connect( m_annotationDisplay, SIGNAL( displayedResourceChanged( Nepomuk::Resource ) ),
             m_annotationWidget, SLOT( setResource( Nepomuk::Resource ) ) );
}


MainWindow::~MainWindow()
{
}
