/*
    Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "annotationdialog.h"
#include "annotationwidget.h"
#include "annotationdisplay.h"

#include <Nepomuk/Thing>

#include <KLineEdit>
#include <KLocale>

#include <QtGui/QGridLayout>
#include <QtGui/QLabel>
#include <QtCore/QTimer>


class Nepomuk::AnnotationDialog::Private
{
public:
    void _k_nameChangeTimeout();

    KLineEdit* editName;
    AnnotationWidget* annotationWidget;
    AnnotationDisplay* annotationDisplay;

    Nepomuk::Resource resource;

    QTimer nameChangeTimer;
};


void Nepomuk::AnnotationDialog::Private::_k_nameChangeTimeout()
{
    if ( resource.pimoThing().label() != editName->text() ) {
        resource.pimoThing().setLabel( editName->text() );
    }
}


Nepomuk::AnnotationDialog::AnnotationDialog( QWidget* parent )
    : KDialog( parent ),
      d( new Private() )
{
    setButtons( KDialog::Ok );
    setDefaultButton( KDialog::Ok );

    QWidget* w = mainWidget();
    QGridLayout* layout = new QGridLayout( w );
    layout->setMargin( 0 );
    layout->setSpacing( spacingHint() );

    d->editName = new KLineEdit( w );
    d->annotationWidget = new AnnotationWidget( w );
    d->annotationDisplay = new AnnotationDisplay( w );

    layout->addWidget( new QLabel( i18nc( "@label:textbox", "Name:" ), w ), 0, 0 );
    layout->addWidget( d->editName, 0, 1 );
    layout->addWidget( new QLabel( i18nc( "@label:textbox", "Annotations:" ), w ), 1, 0 );
    layout->addWidget( d->annotationWidget, 1, 1 );
    layout->addWidget( d->annotationDisplay, 2, 0, 1, 2 );

    // we do not want to update the name on every key press
    d->nameChangeTimer.setInterval( 400 );
    d->nameChangeTimer.setSingleShot( true );

    connect( d->editName, SIGNAL( textChanged( QString ) ),
             &d->nameChangeTimer, SLOT( start() ) );
    connect( &d->nameChangeTimer, SIGNAL( timeout() ),
             this, SLOT( _k_nameChangeTimeout() ) );
}


Nepomuk::AnnotationDialog::~AnnotationDialog()
{
    delete d;
}


void Nepomuk::AnnotationDialog::setResource( const Nepomuk::Resource& res )
{
    d->resource = res;
    d->annotationWidget->setResource( d->resource.pimoThing() );
    d->annotationDisplay->setResource( d->resource.pimoThing() );
    d->editName->setText( d->resource.pimoThing().label() );
}


Nepomuk::Resource Nepomuk::AnnotationDialog::resource() const
{
    return d->resource;
}

#include "annotationdialog.moc"
