/*
    Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "nepomukannotationplugin.h"
#include "annotationdialog.h"

#include <KAction>
#include <KActionCollection>
#include <KLocale>
#include <KIcon>
#include <KMessageBox>
#include <KPluginFactory>
#include <KPluginLoader>
#include <KTemporaryFile>

#include <khtml_part.h>
#include <dom/html_document.h>
#include <dom/dom_string.h>

#include <Nepomuk/Thing>

#include <QtDBus/QDBusMessage>
#include <QtDBus/QDBusConnection>


Nepomuk::KonquerorAnnotationPlugin::KonquerorAnnotationPlugin( QObject* parent, const QVariantList& )
    : KParts::Plugin( parent )
{
    KAction* annotateAction = new KAction( actionCollection() );
    annotateAction->setIcon( KIcon( "nepomuk" ) );
    annotateAction->setText( i18nc( "@action:inmenu", "Annotate page" ) );
    annotateAction->setIconText( i18nc( "@action:intoolbar", "Annotate page" ) );
    annotateAction->setToolTip( i18nc( "@info:tooltip", "Annotate the current web page through Nepomuk" ) );
    connect( annotateAction, SIGNAL( triggered() ), this, SLOT( slotAnnotatePage() ) );
    actionCollection()->addAction( "nepomuk_annotate", annotateAction );
}


Nepomuk::KonquerorAnnotationPlugin::~KonquerorAnnotationPlugin()
{
}


void Nepomuk::KonquerorAnnotationPlugin::slotAnnotatePage()
{
    if ( parent() && parent()->inherits( "KHTMLPart" ) ) {
        KHTMLPart* htmlPart = static_cast<KHTMLPart*>( parent() );
        AnnotationDialog dlg;
        Nepomuk::Resource res( htmlPart->baseURL() );
        // FIXME: do only set something on the resource (store it) if an annotation is created
        if ( !res.pimoThing().isValid() ) {
            // send the page to Strigi for full text search on annotated webpages
            KTemporaryFile tmpFile;
            tmpFile.setAutoRemove( false );
            tmpFile.open();
            QTextStream s( &tmpFile );
            s << htmlPart->htmlDocument().toHTML();
            QDBusMessage msg = QDBusMessage::createMethodCall( "org.kde.nepomuk.services.nepomukstrigiservice",
                                                               "/nepomukstrigiservice",
                                                               "org.kde.nepomuk.Strigi",
                                                               "analyzeResourceFromTempFileAndDeleteTempFile" );
            msg.setArguments( QList<QVariant>()
                              << QString::fromAscii( res.resourceUri().toEncoded() )
                              << QDateTime::currentDateTime().toTime_t()
                              << tmpFile.fileName() );
            QDBusConnection::sessionBus().send( msg );

            res.pimoThing().setLabel( htmlPart->htmlDocument().title().string() );
        }
        dlg.setResource( res );
        dlg.exec();
    }
}

K_PLUGIN_FACTORY(KonquerorAnnotationPluginFactory, registerPlugin<Nepomuk::KonquerorAnnotationPlugin>();)
K_EXPORT_PLUGIN(KonquerorAnnotationPluginFactory("khtml_nepomuk_annotation"))

#include "nepomukannotationplugin.moc"
