/* This file is part of the Nepomuk Project
   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef _PIMOSERVICE_ADAPTOR_H_
#define _PIMOSERVICE_ADAPTOR_H_

#include <QtCore/QObject>
#include <QtDBus/QtDBus>

class QString;

namespace Nepomuk {
    class PimoModel;
    class PimoService;

    class PimoServiceAdaptor: public QDBusAbstractAdaptor
    {
        Q_OBJECT
        Q_CLASSINFO("D-Bus Interface", "org.kde.nepomuk.Pimo")
        Q_CLASSINFO("D-Bus Introspection", ""
                    "  <interface name=\"org.kde.nepomuk.Pimo\" >\n"
                    "    <method name=\"createClass\" >\n"
                    "      <arg direction=\"out\" type=\"s\" name=\"uri\" />\n"
                    "      <arg direction=\"in\" type=\"s\" name=\"parent\" />\n"
                    "      <arg direction=\"in\" type=\"s\" name=\"label\" />\n"
                    "      <arg direction=\"in\" type=\"s\" name=\"comment\" />\n"
                    "      <arg direction=\"in\" type=\"s\" name=\"icon\" />\n"
                    "    </method>\n"
                    "    <method name=\"createProperty\" >\n"
                    "      <arg direction=\"out\" type=\"s\" name=\"uri\" />\n"
                    "      <arg direction=\"in\" type=\"s\" name=\"domain\" />\n"
                    "      <arg direction=\"in\" type=\"s\" name=\"range\" />\n"
                    "      <arg direction=\"in\" type=\"s\" name=\"label\" />\n"
                    "      <arg direction=\"in\" type=\"s\" name=\"comment\" />\n"
                    "      <arg direction=\"in\" type=\"s\" name=\"icon\" />\n"
                    "    </method>\n"
                    "    <method name=\"createThing\" >\n"
                    "      <arg direction=\"out\" type=\"s\" name=\"uri\" />\n"
                    "      <arg direction=\"in\" type=\"s\" name=\"type\" />\n"
                    "      <arg direction=\"in\" type=\"s\" name=\"label\" />\n"
                    "      <arg direction=\"in\" type=\"s\" name=\"comment\" />\n"
                    "      <arg direction=\"in\" type=\"s\" name=\"icon\" />\n"
                    "    </method>\n"
                    "  </interface>\n"
                    "")

    public:
        PimoServiceAdaptor( Nepomuk::PimoService* parent, PimoModel* model );
        ~PimoServiceAdaptor();

    public Q_SLOTS:
        QString createClass( const QString& parent, const QString& label, const QString& comment, const QString& icon );
        QString createProperty( const QString& domain, const QString& range, const QString& label, const QString& comment, const QString& icon );
        QString createThing( const QString& type, const QString& label, const QString& comment, const QString& icon );

    private:
        PimoModel* m_model;
    };
}

#endif
