/* This file is part of the Nepomuk Project
   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "nepomukusercontextservice.h"
#include "nctx.h"
#include "usercontextserviceadaptor.h"

#include <KUrl>
#include <KLocale>
#include <KPluginFactory>
#include <KDebug>

#include <Soprano/Model>
#include <Soprano/StatementIterator>
#include <Soprano/Statement>
#include <Soprano/Node>
#include <Soprano/NodeIterator>
#include <Soprano/QueryResultIterator>
#include <Soprano/Vocabulary/Xesam>

#include <Nepomuk/Resource>
#include <Nepomuk/ResourceManager>
#include <Nepomuk/Variant>


/**
 * this marco creates a service factory which can then be found by the Qt/KDE
 * plugin system in the Nepomuk server.
 */
NEPOMUK_EXPORT_SERVICE( Nepomuk::UserContextService, "nepomukusercontextservice")


Nepomuk::UserContextService::UserContextService( QObject* parent, const QList<QVariant>& )
    : Service( parent )
{
    // only so ResourceManager won't open yet another connection to the nepomuk server
    ResourceManager::instance()->setOverrideMainModel( mainModel() );

    ( void )new UserContextServiceAdaptor( this );
}


Nepomuk::UserContextService::~UserContextService()
{
}


QString Nepomuk::UserContextService::currentUserContext()
{
    // Nepomuk::Service provides convinient access to the main Nepomuk repository via Soprano
    Soprano::QueryResultIterator it = mainModel()->executeQuery( QString( "select ?c where { <%1> <%2> ?c . }" )
                                                                 .arg( Vocabulary::NCTX::ActiveContexts().toString() )
                                                                 .arg( Vocabulary::NCTX::activeUserContext().toString() ),
                                                                 Soprano::Query::QueryLanguageSparql );
    if ( it.next() ) {
        // this is a DBus method, thus convert the URI to encoded for perfect deserialization on the other end
        return QString::fromAscii( it.binding( 0 ).uri().toEncoded() );
    }
    else {
        kDebug() << "No active context found";
        return QString();
    }
}


void Nepomuk::UserContextService::setCurrentUserContext( const QString& uri )
{
    Nepomuk::Resource userState( Vocabulary::NCTX::ActiveContexts(), Vocabulary::NCTX::ContextSet() );

    // setting a property on the object without a URI (in case no old resource was found above) will create
    // a random URI and save the new resource. Otherwise the old value will simply be overwritten
    userState.setProperty( Vocabulary::NCTX::activeUserContext(), Nepomuk::Variant( QUrl::fromEncoded( uri.toAscii() ) ) );

    emit currentUserContextChanged( uri );
}

#include "nepomukusercontextservice.moc"
