/* This file is part of the Nepomuk Project
   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef _NEPOMUK_USER_CONTEXT_SERVICE_H_
#define _NEPOMUK_USER_CONTEXT_SERVICE_H_

#include <Nepomuk/Service>

#include <QtCore/QVariant>


namespace Nepomuk {
    /**
     * Implementing a Nepomuk service is easy: just derive your own
     * service from Nepomuk::Service and provide the appropriate desktop
     * file along with the NEPOMUK_EXPORT_SERVICE macro in the cpp file.
     */
    class UserContextService : public Service
    {
        Q_OBJECT

    public:
        /**
         * both paramters are basically unused but forced by the KDE
         * plugin system.
         */
        UserContextService( QObject* parent, const QVariantList& );
        ~UserContextService();

    public Q_SLOTS:
        /**
         * \return The URI of the currently active user context. An emtpy
         * string if no context is active (ie. the anonymeous context)
         */
        QString currentUserContext();
        void setCurrentUserContext( const QString& uri );

    Q_SIGNALS:
        void currentUserContextChanged( const QString& uri );
    };
}

#endif
